Learn R Programming

ETRep (version 1.2.1)

.etrep_open3d: Open an rgl device with fallback to WebGL

Description

This function tries to open a native rgl window. If that fails (e.g. on macOS without OpenGL) it falls back to an off-screen device suitable for rendering with rglwidget().

Usage

.etrep_open3d(show_widget = TRUE, ...)

Value

Device ID returned by [rgl::open3d()].

Arguments

show_widget

logical; if TRUE and native OpenGL is not available, a message is displayed suggesting to use etrep_show3d().

...

additional arguments passed to [rgl::open3d()].