dot-onLoad: Package startup hook

.onLoadR Documentation

Package startup hook

Description

This special function is called automatically when the ETRep package is loaded. It ensures that 'rgl' uses the off-screen WebGL device ('useNULL = TRUE') on macOS and other headless environments, so that package installation and examples do not fail with an OpenGL error.

Usage

.onLoad(libname, pkgname)

Arguments

libname

Character string; the path to the package library.

pkgname

Character string; the name of the package.

If the user has not already set 'options(rgl.useNULL)', this function sets it to 'TRUE' to suppress the typical warning: "rgl.init failed, will use the null device".


ETRep documentation built on Nov. 5, 2025, 6:34 p.m.

Related to dot-onLoad in ETRep...