elliptical_Tube_Euclideanization: Convert an ETRep to a Matrix in the Convex Transformed Space.

View source: R/ETRep_Functions.R

elliptical_Tube_EuclideanizationR Documentation

Convert an ETRep to a Matrix in the Convex Transformed Space.

Description

Convert an ETRep to a Matrix in the Convex Transformed Space.

Usage

elliptical_Tube_Euclideanization(tube)

Arguments

tube

A list containing the details of the ETRep.

Value

An n*6 matrix, where n is the number of spinal points, representing the ETRep in the transformed Euclidean convex space.

Examples

#Example
# Load tube
data("tube_A")
Euclideanized_Tube<- elliptical_Tube_Euclideanization(tube = tube_A)


ETRep documentation built on Nov. 5, 2025, 6:34 p.m.