intrinsic_mean_tube: Calculate Intrinsic Mean of ETReps

View source: R/ETRep_Functions.R

intrinsic_mean_tubeR Documentation

Calculate Intrinsic Mean of ETReps

Description

Computes the intrinsic mean of a set of ETReps. The computation involves transforming the non-convex hypertrumpet space into a convex space, calculating the mean in this transformed space, and mapping the result back to the original hypertrumpet space.

Usage

intrinsic_mean_tube(tubes, type = "sizeAndShapeAnalysis", plotting = TRUE)

Arguments

tubes

List of ETReps.

type

String, "ShapeAnalysis" or "sizeAndShapeAnalysis" (default is "sizeAndShapeAnalysis").

plotting

Logical, enables visualization of the mean (default is TRUE).

Value

List representing the mean ETRep.

References

Taheri, M., Pizer, S. M., & Schulz, J. (2024). "The Mean Shape under the Relative Curvature Condition." arXiv. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2404.01043")}

Taheri Shalmani, M. (2024). "Shape Statistics via Skeletal Structures." University of Stavanger. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.13140/RG.2.2.34500.23685")}

Examples

#Example 1
# Load tubes
data("tube_A")
data("tube_B")
intrinsic_mean<-
  intrinsic_mean_tube(tubes = list(tube_A,tube_B),
                      plotting = FALSE)
# Plotting
## Not run: 
plot_Elliptical_Tube(tube = intrinsic_mean,
                     plot_frames = FALSE,
                     plot_skeletal_sheet = FALSE,
                     plot_r_project = FALSE,
                     plot_r_max = FALSE,
                     add = FALSE)
 
## End(Not run)

#Example 2
data("simulatedColons")
intrinsic_mean<-
  intrinsic_mean_tube(tubes = simulatedColons,
                      plotting = FALSE)
# Plotting
## Not run: 
plot_Elliptical_Tube(tube = intrinsic_mean,
                     plot_frames = FALSE,
                     plot_skeletal_sheet = FALSE,
                     plot_r_project = FALSE,
                     plot_r_max = FALSE,
                     add = FALSE)
 
## End(Not run)

ETRep documentation built on Nov. 5, 2025, 6:34 p.m.