View source: R/ETRep_Functions.R
| nonIntrinsic_Transformation_Elliptical_Tubes | R Documentation |
Performs a non-intrinsic transformation from one ETRep to another. This approach is inspired by robotic arm transformations and does not account for the Relative Curvature Condition (RCC).
nonIntrinsic_Transformation_Elliptical_Tubes(
tube1,
tube2,
type = "sizeAndShapeAnalysis",
numberOfSteps = 4,
plotting = TRUE,
colorBoundary = "blue",
add = FALSE
)
tube1 |
List containing details of the first ETRep. |
tube2 |
List containing details of the second ETRep. |
type |
String defining the type of analysis as sizeAndShapeAnalysis or shapeAnalysis |
numberOfSteps |
Integer, number of transformation steps. |
plotting |
Logical, enables visualization during transformation (default is TRUE). |
colorBoundary |
String defining the color of the e-tube |
add |
Logical, enables overlay plotting |
List containing intermediate ETReps.
Taheri, M., Pizer, S. M., & Schulz, J. (2024). "The Mean Shape under the Relative Curvature Condition." arXiv. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2404.01043")}
Taheri Shalmani, M. (2024). "Shape Statistics via Skeletal Structures." University of Stavanger. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.13140/RG.2.2.34500.23685")}
# Load tubes
data("tube_A")
data("tube_B")
numberOfSteps <- 10
transformation_Tubes<-
nonIntrinsic_Transformation_Elliptical_Tubes(
tube1 = tube_A,tube2 = tube_B,
numberOfSteps = numberOfSteps,
plotting = FALSE)
# Plotting
## Not run:
for (i in 1:length(transformation_Tubes)) {
plot_Elliptical_Tube(tube = transformation_Tubes[[i]],
plot_frames = FALSE,plot_skeletal_sheet = FALSE
,plot_r_project = FALSE,
plot_r_max = FALSE,
add = FALSE)
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.