| simulatedColons | R Documentation |
Simulated samples of e-tubes, modeled after a reference structure resembling a colon.
simulatedColons
Five simulated samples of elliptical tubes, modeled after a reference structure resembling a colon.
Generated and stored in the package's 'data/' folder.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.