This function tries to open a native rgl window. If that fails (e.g. on macOS without OpenGL) it falls back to an off-screen device suitable for rendering with rglwidget().
.etrep_open3d(show_widget = TRUE, ...)Device ID returned by [rgl::open3d()].
logical; if TRUE and native OpenGL is not available, a message is displayed suggesting to use etrep_show3d().
additional arguments passed to [rgl::open3d()].