| .onLoad | R Documentation |
This special function is called automatically when the ETRep package is loaded. It ensures that 'rgl' uses the off-screen WebGL device ('useNULL = TRUE') on macOS and other headless environments, so that package installation and examples do not fail with an OpenGL error.
.onLoad(libname, pkgname)
libname |
Character string; the path to the package library. |
pkgname |
Character string; the name of the package. If the user has not already set 'options(rgl.useNULL)', this function sets it to 'TRUE' to suppress the typical warning: "rgl.init failed, will use the null device". |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.