View source: R/ETRep_Functions.R
| elliptical_Tube_Euclideanization | R Documentation |
Convert an ETRep to a Matrix in the Convex Transformed Space.
elliptical_Tube_Euclideanization(tube)
tube |
A list containing the details of the ETRep. |
An n*6 matrix, where n is the number of spinal points, representing the ETRep in the transformed Euclidean convex space.
#Example
# Load tube
data("tube_A")
Euclideanized_Tube<- elliptical_Tube_Euclideanization(tube = tube_A)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.